@@ -1,23 +1,24 @@
 ;;; api.scm  --  The style for documenting Scheme APIs.
+;;; -*- coding: iso-8859-1 -*-
 ;;;
-;;; Copyright 2005, 2006, 2007, 2008  Ludovic Courts <ludo@gnu.org>
+;;; Copyright 2005, 2006, 2007, 2008, 2009, 2012  Ludovic Courts <ludo@gnu.org>
 ;;; Copyright 2003, 2004  Manuel Serrano
 ;;;
 ;;;
-;;; This program is free software; you can redistribute it and/or modify
+;;; This file is part of Skribilo.
+;;;
+;;; Skribilo is free software: you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2 of the License, or
+;;; the Free Software Foundation, either version 3 of the License, or
 ;;; (at your option) any later version.
 ;;;
-;;; This program is distributed in the hope that it will be useful,
+;;; Skribilo is distributed in the hope that it will be useful,
 ;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
 ;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ;;; GNU General Public License for more details.
 ;;;
 ;;; You should have received a copy of the GNU General Public License
-;;; along with this program; if not, write to the Free Software
-;;; Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-;;; USA.
+;;; along with Skribilo.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (skribilo documentation api)
   :use-module (skribilo reader)
@@ -27,7 +28,8 @@
   :use-module (skribilo output)
   :use-module (skribilo lib) ;; `define-markup'
   :use-module (skribilo utils compat)
-  :use-module (skribilo utils syntax) ;; `%skribilo-module-reader'
+  :use-module (skribilo utils syntax)
+  :use-module (skribilo utils justify)            ; for `info'
 
   :use-module (skribilo package base)
   :use-module (skribilo documentation manual)
@@ -37,7 +39,7 @@
   :use-module (ice-9 match)
   :use-module (ice-9 optargs))
 
-(fluid-set! current-reader %skribilo-module-reader)
+(skribilo-module-syntax)
 
 
 ;*---------------------------------------------------------------------*/
@@ -92,9 +94,32 @@
   (let ((defs (engine-custom le 'inline-definitions-proc)))
     (engine-custom-set! le 'inline-definitions-proc
                         (lambda (e)
-                          (string-append (defs e) "\n"
-                                         "def @DocHeading right x\n{\n"
-                                         "{ Helvetica Base } @Font x\n}\n"))))
+                          (string-append
+                           (defs e) "\n"
+                           "def @DocHeading right x\n{\n"
+                           "{ Helvetica Base } @Font x\n}\n"
+
+                           "
+# TeX and LaTeX, from Lout's `init' file.
+def @TeX { @OneCol { T &0.4fo {-0.2f @VShift E} &0.45fo X } }
+def @LaTeX { @OneCol { L &0.3fo { +0.1f @VShift 0.8f @Font A } &0.4fo @TeX } }
+
+# The `example' markup.
+def @SkribiloExample named @Title {} right x {
+  @B { @Title }
+  @Floater
+    @OnePage { No }
+    @Location { Display }
+    @Format {
+      @Diag { @CurveBox
+                outlinestyle { noline }
+                paint { rgb 0.95 0.95 0.87 }
+                font { 0.9f }
+		break { 0.9fx }
+              @HExpand @Body } }
+  { x }
+}\n\n"
+                           ))))
 
   (markup-writer 'doc-markup
     :action (lambda (n e)
@@ -161,14 +186,75 @@
                           customs)
                 (display "\n@LP\n")))))
 
-(define (punctuate lst)
-  ;; Punctuate words (ASTs) listed in LST.
+
+;*---------------------------------------------------------------------*/
+;*    Info configuration                                               */
+;*---------------------------------------------------------------------*/
+
+(let ((ie (find-engine 'info)))
+  (markup-writer 'doc-markup ie
+    :action (lambda (n e)
+              (let ((protos (markup-option n 'prototypes))
+                    (opts   (markup-option n 'options))
+                    (params (markup-option n 'parameters))
+                    (see    (markup-option n 'see-also))
+                    (margin *margin*))
+                (output (linebreak) e)
+
+                (with-justification
+                 (make-justifier (- (justification-width) 2) 'left)
+                 (lambda ()
+                   (for-each (lambda (p)
+                               (output "-- Markup: " e)
+                               (output p e))
+                             protos))
+                 (+ *margin* 1))
+
+                (and (pair? opts)
+                     (output
+                      (description
+                       (map (lambda (o)
+                              (let ((name    (car o))
+                                    (engines (cadr o))
+                                    (desc    (caddr o)))
+                                (item :key (list (tt name)
+                                                 " (supported by "
+                                                 (punctuate engines #f)
+                                                 ")")
+                                      desc)))
+                            opts))
+                      e))
+
+                (and (pair? params)
+                     (output
+                      (description
+                       (map (lambda (p)
+                              (let ((name (car p))
+                                    (desc (cdr p)))
+                                (item :key (tt name)
+                                      desc)))
+                            params))
+                      e))
+
+                (and (pair? see)
+                     ;; Since Emacs' Info reader automatically precedes each
+                     ;; *Note with "see ", just write "Also" instead of "See
+                     ;; also".
+                     (output (cons "Also, " (punctuate see)) e))
+
+                (output (linebreak) e)))))
+
+(define* (punctuate lst :optional (period? #t))
+  ;; Punctuate words (ASTs) listed in LST.  If PERIOD? is true, add a
+  ;; terminating period.
   (or (null? lst)
-      (reverse (cons "."
-                     (cdr (fold (lambda (word result)
-                                  (cons* ", " word result))
-                                '()
-                                lst))))))
+      (let ((items (cdr (fold (lambda (word result)
+                                (cons* ", " word result))
+                              '()
+                              lst))))
+        (reverse (if period?
+                     (cons "." items)
+                     items)))))
 
 
 ;*---------------------------------------------------------------------*/
@@ -190,6 +276,7 @@
 			path)
 	  (with-input-from-file f
 	     (lambda ()
+                (set-correct-file-encoding!)
 		(let loop ((exp (read)))
 		   (if (eof-object? exp)
 		       (skribe-error 'api-search-definition
@@ -404,7 +491,7 @@
 	  (tr (td :align 'left exp))))
       (else 
        (match exp
-	  ((and sym (? symbol?))
+          (('quote (? symbol? sym))
 	   (string-append "'" (symbol->string sym)))
 	  (else
 	   (with-output-to-string (lambda () (write exp))))))))
@@ -413,30 +500,38 @@
 ;*    doc-markup-proto ...                                             */
 ;*---------------------------------------------------------------------*/
 (define (doc-markup-proto id options formals rest)
+   (define bold*
+     (if (engine-format? "info")
+         list
+         bold))
+   (define code*
+     (if (engine-format? "info")
+         list
+         code))
    (define (option opt)
       (if (pair? opt)
 	  (if (eq? (cadr opt) #f)
 	      (list " [" (keyword (car opt)) "]")
 	      (list " [" (keyword (car opt)) " " 
-		    (code (exp->skribe (cadr opt))) "]"))
+		    (code* (exp->skribe (cadr opt))) "]"))
 	  (list " " (keyword opt))))
    (define (formal f)
       (list " " (param f)))
-   (code (list (bold "(") (bold :class 'api-proto-ident
-				(format #f "~a" id)))
-	 (map option (sort options 
-			   (lambda (s1 s2)
+   (code* (list (bold* "(") (bold* :class 'api-proto-ident
+                                   (format #f "~a" id)))
+          (map option (sort options
+                            (lambda (s1 s2)
 			      (cond
-				 ((and (pair? s1) (not (pair? s2)))
-				  #f)
-				 ((and (pair? s2) (not (pair? s1)))
-				  #t)
-				 (else
-				  #t)))))
-	 (if (pair? formals)
-	     (map formal formals))
-	 (if rest (list " " (param rest)))
-	 (bold ")")))
+                               ((and (pair? s1) (not (pair? s2)))
+                                #f)
+                               ((and (pair? s2) (not (pair? s1)))
+                                #t)
+                               (else
+                                #t)))))
+          (if (pair? formals)
+              (map formal formals))
+          (if rest (list " " (param rest)))
+          (bold* ")")))
 
 ;*---------------------------------------------------------------------*/
 ;*    doc-markup ...                                                   */
@@ -468,15 +563,18 @@
       (map (lambda (e)
 	      (let* ((id (engine-ident e))
 		     (s (symbol->string id)))
-		 (if (engine-format? "latex")
-		     (list s " ")
-		     (list (if sui
-			       (ref :skribe sui 
-				  :mark (string-append s "-engine") 
-				  :text s)
-			       (ref :mark (string-append s "-engine") 
-				  :text s))
-			   " "))))
+		 (cond ((engine-format? "latex")
+                        (list s " "))
+                       ((engine-format? "info")
+                        s)
+                       (else
+                        (list (if sui
+                                  (ref :skribe sui 
+                                       :ident (string-append s "-engine")
+                                       :text s)
+                                  (ref :ident (string-append s "-engine")
+                                       :text s))
+                              " ")))))
 	   (if (pair? force-engines) 
 	       force-engines 
 	       (filter (lambda (e)
@@ -648,7 +746,7 @@
 			 (subsubsection :title "See also" :number #f :toc #f
 			    (p so)
 			    (! "\\noindent"))))))
-          (define (doc-markup.lout)
+          (define (doc-markup.generic)
 	     (let ((df (map (lambda (f)
 			       (cons (param (car f)) (cadr f)))
 			    dformals))
@@ -698,8 +796,9 @@
 		(cond
 		   ((engine-format? "latex")
 		    (doc-markup.latex))
-                   ((engine-format? "lout")
-                    (doc-markup.lout))
+                   ((or (engine-format? "lout")
+                        (engine-format? "info"))
+                    (doc-markup.generic))
 		   (else
 		    (center (doc-markup.html)))))))))
 
@@ -768,7 +867,3 @@
                                 (map make-row-for-custom
                                      (filter cadr args))))))))))))
 
-
-;;; Local Variables:
-;;; coding: latin-1
-;;; End:
