@@ -1,30 +1,30 @@
 ;;; env.scm  --  The environment variables for the documentation.
 ;;;
-;;; Copyright 2005, 2006, 2007, 2008  Ludovic Courts <ludo@gnu.org>
+;;; Copyright 2005, 2006, 2007, 2008, 2009, 2012  Ludovic Courts <ludo@gnu.org>
 ;;; Copyright 2003, 2004  Manuel Serrano
 ;;;
 ;;;
-;;; This program is free software; you can redistribute it and/or modify
+;;; This file is part of Skribilo.
+;;;
+;;; Skribilo is free software: you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2 of the License, or
+;;; the Free Software Foundation, either version 3 of the License, or
 ;;; (at your option) any later version.
 ;;;
-;;; This program is distributed in the hope that it will be useful,
+;;; Skribilo is distributed in the hope that it will be useful,
 ;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
 ;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ;;; GNU General Public License for more details.
 ;;;
 ;;; You should have received a copy of the GNU General Public License
-;;; along with this program; if not, write to the Free Software
-;;; Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-;;; USA.
+;;; along with Skribilo.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (skribilo documentation env)
   :use-module (skribilo config)
   :use-module (skribilo engine))
 
-(define-public *serrano-url* "http://www.inria.fr/mimosa/Manuel.Serrano")
-(define-public *serrano-mail* "Manuel.Serrano@sophia.inria.fr")
+(define-public *serrano-url* "http://www-sop.inria.fr/members/Manuel.Serrano/")
+(define-public *serrano-mail* "manuel.serrano@inria.fr")
 (define-public *courtes-mail* "ludo@gnu.org")
 (define-public *html-url* "http://www.w3.org/TR/html4")
 (define-public *html-form* "interact/forms.html")
@@ -48,5 +48,5 @@
 (define-public *disp-color* "#ccffcc")
 (define-public *header-color* "#cccccc")
 
-(define-public *api-engines* (map find-engine '(html lout latex context xml)))
+(define-public *api-engines* (map find-engine '(html lout latex context info xml)))
 (define-public *engine-src* "skribilo/engine.scm")
