@@ -1,23 +1,24 @@
 ;;; manual.scm  --  Skribilo manuals and documentation style.
+;;; -*- coding: iso-8859-1 -*-
 ;;;
-;;; Copyright 2007, 2008  Ludovic Courts <ludo@gnu.org>
+;;; Copyright 2007, 2008, 2009, 2012  Ludovic Courts <ludo@gnu.org>
 ;;; Copyright 2003, 2004  Manuel Serrano
 ;;;
 ;;;
-;;; This program is free software; you can redistribute it and/or modify
+;;; This file is part of Skribilo.
+;;;
+;;; Skribilo is free software: you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2 of the License, or
+;;; the Free Software Foundation, either version 3 of the License, or
 ;;; (at your option) any later version.
 ;;;
-;;; This program is distributed in the hope that it will be useful,
+;;; Skribilo is distributed in the hope that it will be useful,
 ;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
 ;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ;;; GNU General Public License for more details.
 ;;;
 ;;; You should have received a copy of the GNU General Public License
-;;; along with this program; if not, write to the Free Software
-;;; Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-;;; USA.
+;;; along with Skribilo.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (skribilo documentation manual)
   :use-module (skribilo engine)
@@ -41,7 +42,7 @@
   :use-module (srfi srfi-13)
   :use-module (srfi srfi-37))
 
-(fluid-set! current-reader %skribilo-module-reader)
+(skribilo-module-syntax)
 
 
 ;*---------------------------------------------------------------------*/
@@ -82,12 +83,8 @@
                       (number (markup-option n :number))
                       (legend (markup-option n :legend)))
                   (evaluate-document (mark ident) e)
-                  (display "\n@LP\n5c @Wide @FullWidthRule\n@LP\n")
-                  (output (list (! "{ Schoolbook Bold 1.0f } @Font { $1 }"
-                                   (list (format #f "Example ~a. " number)
-                                         legend))
-                                (! "\n@LP\n")
-                                (markup-body n))
+                  (output (! "\n@LP\n@SkribiloExample @Title { Example $1.  $2 } { $3 }\n"
+                             number legend (markup-body n))
                           e)))))
 
 
@@ -161,6 +158,8 @@
    (engine-custom-set! le 'document-type 'book)
    (engine-custom-set! le 'document-include
                        "@Include { \"book-style.lout\" }")
+   (engine-custom-set! le 'includes
+                       "@SysInclude { tbl }\n@SysInclude { diag }\n")
    (engine-custom-set! le 'initial-language "English")
    (engine-custom-set! le 'initial-font "Palatino Base 10p")
    (engine-custom-set! le 'on-title-page (! "@Include { \"front-page.lout\" }")))
@@ -253,7 +252,8 @@
 	       ((keyword? arg)
 		(with-output-to-string
 		  (lambda ()
-		    (write arg))))
+                    (display ":")
+		    (display (keyword->symbol arg)))))
 	       ((symbol? arg)
 		(string-append ":" (symbol->string arg)))
 	       (else
@@ -267,7 +267,11 @@
       ((keyword? arg)
        (keyword arg))
       ((symbol? arg)
-       (code (symbol->string arg)))
+       (resolve (lambda (n e env)
+                  (let ((arg (symbol->string arg)))
+                    (if (engine-format? "info" e)
+                        (string-upcase arg)
+                        (code arg))))))
       (else
        arg)))
 
