@@ -1,23 +1,23 @@
 ;;; skribilo.scm  --  The Skribilo document processor.
 ;;;
-;;; Copyright 2005, 2006, 2007, 2008  Ludovic Courts <ludo@gnu.org>
+;;; Copyright 2005, 2006, 2007, 2008, 2009, 2011, 2012  Ludovic Courts <ludo@gnu.org>
 ;;; Copyright 2003, 2004  Erick Gallesio - I3S-CNRS/ESSI <eg@unice.fr>
 ;;;
 ;;;
-;;; This program is free software; you can redistribute it and/or modify
+;;; This file is part of Skribilo.
+;;;
+;;; Skribilo is free software: you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2 of the License, or
+;;; the Free Software Foundation, either version 3 of the License, or
 ;;; (at your option) any later version.
 ;;;
-;;; This program is distributed in the hope that it will be useful,
+;;; Skribilo is distributed in the hope that it will be useful,
 ;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
 ;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ;;; GNU General Public License for more details.
 ;;;
 ;;; You should have received a copy of the GNU General Public License
-;;; along with this program; if not, write to the Free Software
-;;; Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-;;; USA.
+;;; along with Skribilo.  If not, see <http://www.gnu.org/licenses/>.
 
 ;;; Commentary:
 ;;;
@@ -40,7 +40,8 @@
   :use-module  (skribilo parameters)
   :use-module  (skribilo config)
 
-  :autoload    (srfi srfi-1)     (alist-cons)
+  :use-module  (srfi srfi-1)
+  :use-module  (srfi srfi-13)
   :use-module  (srfi srfi-37)
   :use-module  (srfi srfi-39)
 
@@ -48,7 +49,7 @@
 
 
 ;; Install the Skribilo module syntax reader.
-(fluid-set! current-reader %skribilo-module-reader)
+(skribilo-module-syntax)
 
 (if (not (keyword? :kw))
     (error "guile-reader sucks"))
@@ -60,38 +61,60 @@
 ;;;
 
 (define (skribilo-show-help)
-  (format #t "Usage: skribilo [OPTIONS] [INPUT]
+  (display (_ "Usage: skribilo [OPTIONS] [INPUT]"))
+  (display (_ "
 Process Skribilo document from file INPUT (or the standard input) using the
 specified reader syntax, and produce its output using the specified engine.
-
+"))
+  (display (_ "
   -R, --reader=READER    Use READER to parse the input file, e.g., `skribe'
-                         (default) or `outline'.
-  -t, --target=ENGINE    Use ENGINE as the output engine, e.g., `html'.
-  -o, --output=FILE      Write output to FILE.
-      --compat=COMPAT    Use COMPAT as the compatibility layer, e.g., `skribe'.
-
-  -I, --doc-path=DIR     Prepend DIR to the document include path.
-  -B, --bib-path=DIR     Prepend DIR to the bibliography include path.
-  -S, --source-path=DIR  Prepend DIR to the source include path.
-  -P, --image-path=DIR   Prepend DIR to the image include path.
-  -U, --sui-path=DIR     Prepend DIR to the Skribe URL Index (SUI) search path.
-
-  -b, --base=BASE        Strip BASE from all hyperlinks (`html' engine).
+                         (default) or `outline'."))
+  (display (_ "
+  -t, --target=ENGINE    Use ENGINE as the output engine, e.g., `html'."))
+  (display (_ "
+  -c, --custom=C=VAL     Use VAL as the value of ENGINE's custom C."))
+  (display (_ "
+  -o, --output=FILE      Write output to FILE."))
+  (display (_ "
+      --compat=COMPAT    Use COMPAT as the compatibility layer, e.g., `skribe'."))
+  (newline)
+  (display (_ "
+  -I, --doc-path=DIR     Prepend DIR to the document include path."))
+  (display (_ "
+  -B, --bib-path=DIR     Prepend DIR to the bibliography include path."))
+  (display (_ "
+  -S, --source-path=DIR  Prepend DIR to the source include path."))
+  (display (_ "
+  -P, --image-path=DIR   Prepend DIR to the image include path."))
+  (display (_ "
+  -U, --sui-path=DIR     Prepend DIR to the Skribe URL Index (SUI) search path."))
+  (newline)
+  (display (_ "
+  -b, --base=BASE        Strip BASE from all hyperlinks (`html' engine)."))
+  (display (_ "
   -e, --eval=EXPR        Prepend EXPR to the list of expressions to be
-                         evaluted before the input file is processed.
-  -p, --preload=FILE     Preload FILE before processing the input file.
-
-  -v, --verbose[=LEVEL]  Be verbose, unless LEVEL is 0.
-  -w, --warning[=LEVEL]  Issue warnings, unless LEVEL is 0.
+                         evaluted before the input file is processed."))
+  (display (_ "
+  -p, --preload=FILE     Preload FILE before processing the input file."))
+  (newline)
+  (display (_ "
+  -v, --verbose[=LEVEL]  Be verbose, unless LEVEL is 0."))
+  (display (_ "
+  -w, --warning[=LEVEL]  Issue warnings, unless LEVEL is 0."))
+  (display (_ "
   -g, --debug[=ARG]      Issue debugging output, unless ARG is 0.  If ARG is
                          not a number, it is interpreted as a symbol to be
-                         watched.
-      --no-color         Disable colored debugging output.
-
-  -h, --help             Give this help list
-  -V, --version          Print program version
-
-Report bugs to <~a>.~%"
+                         watched."))
+  (display (_ "
+      --no-color         Disable colored debugging output."))
+  (newline)
+  (display (_ "
+  -h, --help             Give this help list"))
+  (display (_ "
+  -V, --version          Print program version"))
+  (newline)
+  (format #t (_ "
+Report bugs to <~a>.~%")
           (skribilo-bug-report-address)))
 
 (define (skribilo-show-version)
@@ -166,6 +189,29 @@ Report bugs to <~a>.~%"
         (option '(#\t "target") #t #f
                 (lambda (opt name arg result)
                   (alist-cons :target arg result)))
+        (option '(#\c "custom") #t #f
+                (lambda (opt name arg result)
+                  (let ((=-pos (string-index arg #\=)))
+                    (if (not =-pos)
+                        (leave (_ "~a: missing value for custom") arg)
+                        (let ((custom (string-take arg =-pos))
+                              (value  (string-drop arg (+ =-pos 1))))
+                          (catch 'read-error
+                            (lambda ()
+                              (let ((custom (string->symbol custom))
+                                    (value
+                                     (with-input-from-string value read))
+                                    (result
+                                     (alist-delete :customs result eq?))
+                                    (customs
+                                     (assoc-ref result :customs)))
+                                (alist-cons
+                                 :customs
+                                 (alist-cons custom value customs)
+                                 result)))
+                            (lambda (key . args)
+                              (leave (_ "~a: invalid custom value")
+                                     value))))))))
         (option '(#\o "output") #t #f
                 (lambda (opt name arg result)
                   (if (assoc :output result)
@@ -242,6 +288,7 @@ Report bugs to <~a>.~%"
     (:source-path ".")
     (:image-path  ".")
     (:sui-path    ".")
+    (:customs)
     (:watched-symbols)))
 
 (define (parse-args args)
@@ -266,6 +313,7 @@ options."
 
 	 (reader-name       (string->symbol (assoc-ref options :reader)))
 	 (engine            (string->symbol (assoc-ref options :target)))
+         (customs           (assoc-ref options :customs))
          (input-file        (assoc-ref options :input))
 	 (output-file       (assoc-ref options :output))
 
@@ -292,6 +340,8 @@ options."
       ;; The environment in which the document is evaluated.
       (make-user-module (string->symbol compat)))
 
+    ;; Install the user-specified locale.
+    (setlocale LC_ALL "")
 
     (if (> (*debug*) 4)
 	(set! %load-hook
@@ -316,6 +366,14 @@ options."
       ;; Load the user rc file (FIXME)
       ;;(load-rc)
 
+      (or (null? customs)
+          (let ((engine (lookup-engine engine)))
+            (for-each (lambda (custom+value)
+                        (let ((custom (car custom+value))
+                              (value  (cdr custom+value)))
+                          (engine-custom-set! engine custom value)))
+                      customs)))
+
       ;; Evaluate expressions passed as `--eval'.
       (for-each (lambda (expr)
                   (eval expr user-module))
@@ -338,23 +396,27 @@ options."
       (if (and output-file (file-exists? output-file))
           (delete-file output-file))
 
-      (parameterize ((*destination-file* output-file)
-                     (*source-file*      input-file)
-                     (*skribilo-output-port*
-                      (if (string? output-file)
-                          (open-output-file output-file)
-                          (current-output-port))))
+      ;; Choose UTF-8 as the default encoding so that string ports will
+      ;; accept all of Unicode.
+      (default-to-utf-8
+        (parameterize ((*destination-file* output-file)
+                       (*source-file*      input-file)
+                       (*skribilo-output-port*
+                        (if (string? output-file)
+                            (open-output-file output-file)
+                            (current-output-port))))
 
-        (setvbuf (*skribilo-output-port*) _IOFBF 16384)
+          (setvbuf (*skribilo-output-port*) _IOFBF 16384)
 
-        (if input-file
-            (with-input-from-file input-file
-              (lambda ()
-                (doskribe user-module)))
-            (doskribe user-module))
+          (if input-file
+              (with-input-from-file input-file
+                (lambda ()
+                  (set-correct-file-encoding!)
+                  (doskribe user-module)))
+              (doskribe user-module))
 
-        ;; Make sure the output port is flushed before we leave.
-        (force-output (*skribilo-output-port*))))))
+          ;; Make sure the output port is flushed before we leave.
+          (force-output (*skribilo-output-port*)))))))
 
 
 ;;; Local Variables:
