@@ -1,28 +1,29 @@
 ;;; ast.scm  --  Skribilo abstract syntax trees.
 ;;;
-;;; Copyright 2003, 2004  Erick Gallesio - I3S-CNRS/ESSI <eg@unice.fr>
+;;; Copyright 2003, 2004, 2009  Erick Gallesio - I3S-CNRS/ESSI <eg@unice.fr>
 ;;; Copyright 2003, 2004  Manuel Serrano
-;;; Copyright 2005, 2006, 2007  Ludovic Courts <ludovic.courtes@laas.fr>
+;;; Copyright 2005, 2006, 2007, 2012  Ludovic Courts <ludo@gnu.org>
 ;;;
 ;;;
-;;; This program is free software; you can redistribute it and/or modify
+;;; This file is part of Skribilo.
+;;;
+;;; Skribilo is free software: you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2 of the License, or
+;;; the Free Software Foundation, either version 3 of the License, or
 ;;; (at your option) any later version.
 ;;;
-;;; This program is distributed in the hope that it will be useful,
+;;; Skribilo is distributed in the hope that it will be useful,
 ;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
 ;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ;;; GNU General Public License for more details.
 ;;;
 ;;; You should have received a copy of the GNU General Public License
-;;; along with this program; if not, write to the Free Software
-;;; Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-;;; USA.
+;;; along with Skribilo.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (skribilo ast)
   :use-module (oop goops)
 
+  :use-module (srfi srfi-1)
   :use-module (srfi srfi-13)
   :use-module (srfi srfi-34)
   :use-module (srfi srfi-35)
@@ -30,8 +31,8 @@
   :use-module (skribilo utils syntax)
 
   :autoload (skribilo location) (location?)
-  :autoload (srfi srfi-1)  (fold concatenate)
 
+  :use-module (ice-9 match)
   :use-module (ice-9 optargs)
 
   :export (<ast> ast? ast-loc ast-loc-set!
@@ -42,6 +43,7 @@
 	   <unresolved> unresolved? unresolved-proc
 	   <handle> handle? handle-ast handle-body
 	   <node> node? node-options node-loc node-body
+                  node-children
 	   <processor> processor? processor-combinator processor-engine
 
 	   <markup> markup? markup-options is-markup?
@@ -92,7 +94,7 @@
 ;;;
 ;;; Code:
 
-(fluid-set! current-reader %skribilo-module-reader)
+(skribilo-module-syntax)
 
 
 
@@ -274,6 +276,21 @@
        (equal? (node-body a)
                (node-body b))))
 
+(define (node-children n)
+  ;; Return the children of N, even those found in sub-lists of N's body.
+  (reverse
+   (let loop ((body   (node-body n))
+              (result '()))
+     (match body
+       (()
+        result)
+       (((? node? n) rest ...)
+        (loop rest (cons n result)))
+       (((sub-list ...) rest ...)
+        (loop rest (loop sub-list result)))
+       ((_ rest ...)
+        (loop rest result))))))
+
 (define node-loc	   ast-loc)
 
 (define-method (ast->string (ast <node>))
@@ -496,11 +513,29 @@
   (if (document-nodes-bound? doc)
       #t
       (begin
-	(ast-fold (lambda (node result)
-		    (if (markup? node) (document-bind-node! doc node))
-		    #t)
-		  #t ;; unused
-		  doc)
+        (let loop ((node doc)
+                   (doc  doc))
+          (cond ((document? node)
+                 ;; Bind NODE in its parent's document.  This is so
+                 ;; that (i) a sub-document is bound in its parent
+                 ;; document, and (ii) a node within a sub-document
+                 ;; is bound in this sub-document.
+                 (document-bind-node! doc node)
+                 (loop (markup-body node) node))
+
+                ((markup? node)
+                 (document-bind-node! doc node)
+                 (loop (markup-body node) doc))
+
+                ((node? node)
+                 (loop (node-body node) doc))
+
+                ((pair? node)
+                 (for-each (lambda (n) (loop n doc)) node))
+
+                ((command? node)
+                 (loop (command-body node) doc))))
+
 	(slot-set! doc 'nodes-bound? #t))))
 
 
@@ -509,8 +544,8 @@
 ;;;
 
 (define (ast-fold proc init ast)
-  ;; Apply PROC to each node in AST (per `node?'), in a way similar to `fold'
-  ;; (in SRFI-1).
+  ;; Do a depth-first traversal of AST, applying PROC to each node in AST
+  ;; (per `node?'), in a way similar to SRFI-1 `fold'.
   (let loop ((ast ast)
 	     (result init))
     (cond ((pair? ast)
