@@ -1,23 +1,24 @@
 ;;; biblio.scm  --  Bibliography functions.
+;;; -*- coding: iso-8859-1 -*-
 ;;;
+;;; Copyright 2005, 2006, 2007, 2009  Ludovic Courts <ludo@gnu.org>
 ;;; Copyright 2001, 2002, 2003, 2004  Manuel Serrano
 ;;; Copyright 2003, 2004  Erick Gallesio - I3S-CNRS/ESSI <eg@essi.fr>
-;;; Copyright 2005, 2006, 2007  Ludovic Courts <ludovic.courtes@laas.fr>
 ;;;
-;;; This program is free software; you can redistribute it and/or modify
+;;; This file is part of Skribilo.
+;;;
+;;; Skribilo is free software: you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2 of the License, or
+;;; the Free Software Foundation, either version 3 of the License, or
 ;;; (at your option) any later version.
 ;;;
-;;; This program is distributed in the hope that it will be useful,
+;;; Skribilo is distributed in the hope that it will be useful,
 ;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
 ;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ;;; GNU General Public License for more details.
 ;;;
 ;;; You should have received a copy of the GNU General Public License
-;;; along with this program; if not, write to the Free Software
-;;; Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-;;; USA.main.st
+;;; along with Skribilo.  If not, see <http://www.gnu.org/licenses/>.
 
 
 
@@ -30,7 +31,7 @@
   :use-module (srfi srfi-39)
   :use-module (skribilo condition)
 
-  :autoload   (skribilo reader)       (%default-reader)
+  :autoload   (skribilo reader)       (*document-reader*)
   :autoload   (skribilo parameters)   (*bib-path*)
   :autoload   (skribilo ast)          (<markup> <handle> is-markup?)
   :autoload   (skribilo lib)          (skribe-warning)
@@ -73,7 +74,7 @@
 ;;;
 ;;; Code:
 
-(fluid-set! current-reader %skribilo-module-reader)
+(skribilo-module-syntax)
 
 
 
@@ -195,7 +196,7 @@
 ;;;
 
 (define (parse-bib table port)
-  (let ((read %default-reader)) ;; FIXME: We should use a fluid
+  (let ((read (*document-reader*)))
     (if (not (bib-table? table))
         (raise (condition
                 (&invalid-argument-error (proc-name "parse-bib")
