@@ -1,28 +1,30 @@
 ;;; condition.scm  --  Skribilo SRFI-35 error condition hierarchy.
+;;; -*- coding: iso-8859-1 -*-
 ;;;
 ;;; Copyright 2006, 2007, 2008  Ludovic Courts  <ludo@gnu.org>
 ;;;
 ;;;
-;;; This program is free software; you can redistribute it and/or modify
+;;; This file is part of Skribilo.
+;;;
+;;; Skribilo is free software: you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2 of the License, or
+;;; the Free Software Foundation, either version 3 of the License, or
 ;;; (at your option) any later version.
 ;;;
-;;; This program is distributed in the hope that it will be useful,
+;;; Skribilo is distributed in the hope that it will be useful,
 ;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
 ;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ;;; GNU General Public License for more details.
 ;;;
 ;;; You should have received a copy of the GNU General Public License
-;;; along with this program; if not, write to the Free Software
-;;; Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-;;; USA.
+;;; along with Skribilo.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (skribilo condition)
   :autoload   (srfi srfi-1)  (find)
-  :autoload   (srfi srfi-34) (guard)
+  :autoload   (srfi srfi-34) (with-exception-handler)
   :use-module (srfi srfi-35)
   :use-module (srfi srfi-39)
+  :autoload   (skribilo parameters)   (*destination-file*)
   :autoload   (skribilo utils syntax) (_ N_)
   :export     (&skribilo-error skribilo-error?
 	       &invalid-argument-error invalid-argument-error?
@@ -118,45 +120,69 @@
 ;;; Convenience functions.
 ;;;
 
+(define (show-stack-trace)
+  ;; Display a backtrace to stderr if possible.
+  (let ((stack (make-stack #t)))
+    (if stack
+        (begin
+          (format (current-error-port) "~%Call stack:~%")
+          (display-backtrace stack (current-error-port)))
+        (begin
+          (format (current-error-port) (_ "Call stack trace not available.~%"))
+          (format (current-error-port) (_ "Use `GUILE=\"guile --debug\" skribilo ...' for a detailed stack trace.~%"))))))
+
+(define (abort exit-val)
+  ;; Abort the `skribilo' command-line program, returning EXIT-VAL.
+
+  ;; XXX: Whether this works depends on whether `with-exception-handler' is
+  ;; broken, see below.
+  (and (string? (*destination-file*))
+       (false-if-exception (delete-file (*destination-file*))))
+
+  (show-stack-trace)
+  (exit exit-val))
+
 (define (%call-with-skribilo-error-catch thunk exit exit-val)
-  (guard (c ((invalid-argument-error? c)
+  (with-exception-handler
+   (lambda (c)
+     (cond  ((invalid-argument-error? c)
 	     (format (current-error-port)
                      (_ "in `~a': invalid argument: ~S~%")
 		     (invalid-argument-error:proc-name c)
 		     (invalid-argument-error:argument c))
-	     (exit exit-val))
+	     (abort exit-val))
 
 	    ((too-few-arguments-error? c)
 	     (format (current-error-port)
                      (_ "in `~a': too few arguments: ~S~%")
 		     (too-few-arguments-error:proc-name c)
 		     (too-few-arguments-error:arguments c))
-             (exit exit-val))
+             (abort exit-val))
 
 	    ((file-search-error? c)
 	     (format (current-error-port)
                      (_ "~a: not found in path `~S'~%")
 		     (file-error:file-name c)
 		     (file-search-error:path c))
-	     (exit exit-val))
+	     (abort exit-val))
 
 	    ((file-open-error? c)
 	     (format (current-error-port)
                      (_ "~a: cannot open file~%")
 		     (file-error:file-name c))
-	     (exit exit-val))
+	     (abort exit-val))
 
 	    ((file-write-error? c)
 	     (format (current-error-port)
                      (_ "~a: cannot write to file~%")
 		     (file-error:file-name c))
-	     (exit exit-val))
+	     (abort exit-val))
 
 	    ((file-error? c)
 	     (format (current-error-port)
                      (_ "file error: ~a~%")
 		     (file-error:file-name c))
-	     (exit exit-val))
+	     (abort exit-val))
 
 	    ((skribilo-error? c)
 	     (let ((handler (lookup-error-condition-handler c)))
@@ -165,13 +191,18 @@
 		   (format (current-error-port)
 			   (_ "undefined skribilo error: ~S~%")
 			   c)))
-	     (exit exit-val))
+	     (abort exit-val))
 
             ((message-condition? c)
              (format (current-error-port) (condition-message c))
-             (exit exit-val)))
+             (abort exit-val))
 
-	 (thunk)))
+            (else
+             (format (current-error-port)
+                     (_ "unexpected error condition: ~A~%") c)
+             (abort exit-val))))
+
+   thunk))
 
 (define-macro (call-with-skribilo-error-catch thunk)
   `(call/cc (lambda (cont)
@@ -180,5 +211,18 @@
 (define (call-with-skribilo-error-catch/exit thunk)
   (%call-with-skribilo-error-catch thunk primitive-exit 1))
 
+
+;;;
+;;; SRFI-34 replacement.
+;;;
+
+(define (with-exception-handler handler thunk)
+  ;; Work around a "bug" in `with-exception-handler' in Guile up to 1.8.5.
+  ;; See http://thread.gmane.org/gmane.lisp.guile.user/6969 for details.
+  ;; XXX: This code is useless for 1.8.6 and later.
+  (with-throw-handler 'srfi-34
+                      thunk
+                      (lambda (key obj)
+                        (handler obj))))
 
 ;;; conditions.scm ends here
