@@ -1,23 +1,24 @@
 ;;; base.scm  --  BASE Skribe engine
+;;; -*- coding: iso-8859-1 -*-
 ;;;
 ;;; Copyright 2006, 2007  Ludovic Courts <ludo@gnu.org>
 ;;; Copyright 2003, 2004  Manuel Serrano
 ;;;
 ;;;
-;;; This program is free software; you can redistribute it and/or modify
+;;; This file is part of Skribilo.
+;;;
+;;; Skribilo is free software: you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2 of the License, or
+;;; the Free Software Foundation, either version 3 of the License, or
 ;;; (at your option) any later version.
 ;;;
-;;; This program is distributed in the hope that it will be useful,
+;;; Skribilo is distributed in the hope that it will be useful,
 ;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
 ;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ;;; GNU General Public License for more details.
 ;;;
 ;;; You should have received a copy of the GNU General Public License
-;;; along with this program; if not, write to the Free Software
-;;; Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-;;; USA.
+;;; along with Skribilo.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (skribilo engine base)
   :use-module (skribilo ast)
@@ -35,7 +36,7 @@
 
   :export (base-engine))
 
-(fluid-set! current-reader %skribilo-module-reader)
+(skribilo-module-syntax)
 
 
 ;*---------------------------------------------------------------------*/
@@ -472,7 +473,7 @@
 			       (make-column ie pref)))
 			   (else
 			    (table :width 100.
-			       ;;:&skribe-eval-location loc
+			       :&location loc
 			       :class "index-table"
 			       (make-sub-tables ie nc pref))))))
 		 (output (evaluate-document t e) e))))
