@@ -1,23 +1,24 @@
 ;;; html.scm  --  HTML engine.
+;;; -*- coding: iso-8859-1 -*-
 ;;;
-;;; Copyright 2005, 2006, 2007, 2008  Ludovic Courts <ludo@gnu.org>
+;;; Copyright 2005, 2006, 2007, 2008, 2009, 2011, 2012  Ludovic Courts <ludo@gnu.org>
 ;;; Copyright 2003, 2004  Manuel Serrano
 ;;;
 ;;;
-;;; This program is free software; you can redistribute it and/or modify
+;;; This file is part of Skribilo.
+;;;
+;;; Skribilo is free software: you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2 of the License, or
+;;; the Free Software Foundation, either version 3 of the License, or
 ;;; (at your option) any later version.
 ;;;
-;;; This program is distributed in the hope that it will be useful,
+;;; Skribilo is distributed in the hope that it will be useful,
 ;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
 ;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ;;; GNU General Public License for more details.
 ;;;
 ;;; You should have received a copy of the GNU General Public License
-;;; along with this program; if not, write to the Free Software
-;;; Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-;;; USA.
+;;; along with Skribilo.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (skribilo engine html)
   :use-module (skribilo lib)
@@ -39,6 +40,7 @@
   :autoload   (ice-9 rdelim)           (read-line)
   :autoload   (ice-9 regex)            (regexp-substitute/global)
 
+  :use-module (srfi srfi-1)
   :use-module (srfi srfi-13)
   :use-module (srfi srfi-14)
   :use-module (srfi srfi-39)
@@ -47,7 +49,7 @@
            html-width html-class html-markup-class
            html-title-authors))
 
-(fluid-set! current-reader %skribilo-module-reader)
+(skribilo-module-syntax)
 
 
 
@@ -57,6 +59,14 @@
 (if (not (engine? base-engine))
     (error "bootstrap problem: base engine broken" base-engine))
 
+(define unspecified?
+  ;; XXX: Hack to recognize the unspecified value as understood by
+  ;; `engine-custom' et al.
+  (let ((really-unspecified? unspecified?))
+    (lambda (x)
+      (or (really-unspecified? x)
+          (eq? x 'unspecified)))))
+
 ;*---------------------------------------------------------------------*/
 ;*    html-file-default ...                                            */
 ;*---------------------------------------------------------------------*/
@@ -598,7 +608,6 @@
 
                  ;; Record the file name, for use by `html-file-default'.
                  (markup-option-add! n :file (*destination-file*))
-
 		 (&html-generic-document n title e)))
 
    :after (lambda (n e)
@@ -936,7 +945,10 @@
 			      (format #t "<a name=\"footnote-~a\">"
 				      (string-canonicalize
 				       (container-ident fn)))
-			      (format #t "<sup><small>~a</small></sup></a>: "
+                              (format #t "<a href=\"#footnote-site-~a\">"
+                                      (string-canonicalize
+                                       (container-ident fn)))
+			      (format #t "<sup><small>~a</small></sup></a></a> "
 				      (markup-option fn :label))
 			      (output (markup-body fn) e)
 			      (display "\n<br>\n")
@@ -1134,10 +1146,37 @@
 
 			  (display "</tbody>\n</table>\n")))))))
 
+(define (section-in-separate-file? n e)
+  ;; Return true if N, a node (chapter, section, etc.), is to be put in a
+  ;; separate file, according to the customs of engine E.
+  (and (container? n)
+       (not (document? n))
+       (or (markup-option n :file)
+           (let ((kind (markup-markup n)))
+             (engine-custom e (string->symbol
+                               (string-append (symbol->string kind)
+                                              "-file")))))))
+
+(define (section-in-current-file? n e)
+  ;; Return true if N is to be output in the current file, or in the main
+  ;; file.
+  (and (container? n)
+       (not (section-in-separate-file? n e))))
+
 ;*---------------------------------------------------------------------*/
 ;*    &html-generic-document ...                                       */
 ;*---------------------------------------------------------------------*/
 (define (&html-generic-document n title e)
+  (define (set-output-encoding)
+    (cond-expand
+     (guile-2
+      ;; Make sure the output is suitably encoded.
+      (and=> (engine-custom e 'charset)
+             (lambda (charset)
+               (set-port-encoding! (current-output-port) charset)
+               (set-port-conversion-strategy! (current-output-port) 'error))))
+     (else #t)))
+
    (let* ((id (markup-ident n))
 	  (header (new markup
 		     (markup '&html-chapter-header)
@@ -1162,8 +1201,24 @@
 		     (ident (string-append id "-footnote"))
 		     (class (markup-class n))
 		     (parent n)
-		     (body (reverse!
-			    (container-env-get n 'footnote-env)))))
+
+		     (body
+                      ;; Collect the footnotes of all the sub-containers that
+                      ;; are to be output in the same file.
+                      (let ((subsections
+                             (find-down (lambda (s)
+                                          (section-in-current-file? s e))
+                                        n)))
+                        (reverse
+                         (let loop ((subsections (cons n subsections))
+                                    (footnotes   '()))
+                           (cond ((pair? subsections)
+                                  (fold loop footnotes subsections))
+                                 ((null? subsections)
+                                  footnotes)
+                                 (else
+                                  (container-env-get subsections
+                                                     'footnote-env)))))))))
 	  (page (new markup
 		   (markup '&html-page)
 		   (ident (string-append id "-page"))
@@ -1193,10 +1248,13 @@
       ;; No file must be opened for documents. These files are
       ;; directly opened by Skribe
       (if (document? n)
-	  (output html e)
+          (begin
+            (set-output-encoding)
+            (output html e))
           (parameterize ((*destination-file* (html-file n e)))
             (with-output-to-file (*destination-file*)
               (lambda ()
+                (set-output-encoding)
 		(output html e)))))))
 
 ;*---------------------------------------------------------------------*/
@@ -1248,7 +1306,7 @@
 		 (display " -->\n")
 		 (display "<a name=\"")
 		 (display (string-canonicalize ident))
-		 (display "\"></a>\n")
+		 (display "\"></a>")
 		 (display "<center><h1")
 		 (html-class n)
 		 (display ">")
@@ -1286,7 +1344,7 @@
       (display " -->\n")
       (display "<a name=\"")
       (display (string-canonicalize ident))
-      (display "\"></a>\n")
+      (display "\"></a>")
       (if c
 	  (format #t "<div class=\"~a-title\">" c)
 	  (format #t "<div class=\"skribilo-~a-title\">" (markup-markup n)))
@@ -1383,9 +1441,12 @@
 (markup-writer 'footnote
    :options '(:label)
    :action (lambda (n e)
+              (format #t "<a name=\"footnote-site-~a\">"
+                      (string-canonicalize (container-ident n)))
 	      (format #t "<a href=\"#footnote-~a\"><sup><small>~a</small></sup></a>"
 		      (string-canonicalize (container-ident n))
-		      (markup-option n :label))))
+		      (markup-option n :label))
+              (format #t "</a>")))
 
 ;*---------------------------------------------------------------------*/
 ;*    linebreak ...                                                    */
@@ -1558,7 +1619,7 @@
 			   (html-class item)
 			   (display ">")
 			    (if ident  ;; produce an anchor
-				(format #t "\n<a name=\"~a\"></a>\n"
+				(format #t "\n<a name=\"~a\"></a>"
 					(string-canonicalize ident)))
 			   (output item e)
 			    (display "</li>\n")))
@@ -1579,7 +1640,7 @@
 			   (html-class item)
 			   (display ">")
 			    (if ident  ;; produce an anchor
-				(format #t "\n<a name=\"~a\"></a>\n" ident))
+				(format #t "\n<a name=\"~a\"></a>" ident))
 			   (output item e)
 			    (display "</li>\n")))
 			(markup-body n)))
@@ -1648,7 +1709,7 @@
 		    (legend (markup-option n :legend)))
 		 (display "<a name=\"")
 		 (display (string-canonicalize ident))
-		 (display "\"></a>\n")
+		 (display "\"></a>")
 		 (output (markup-body n) e)
 		 (display "<br>\n")
 		 (output (new markup
@@ -2262,5 +2323,4 @@
 
 ;;; Local Variables:
 ;;; mode: scheme
-;;; coding: latin-1
 ;;; End:
