@@ -1,23 +1,24 @@
 ;;; latex.scm  --  LaTeX engine.
+;;; -*- coding: iso-8859-1 -*-
 ;;;
-;;; Copyright 2007  Ludovic Courts <ludo@gnu.org>
+;;; Copyright 2007, 2009, 2012  Ludovic Courts <ludo@gnu.org>
 ;;; Copyright 2003, 2004  Manuel Serrano
 ;;;
 ;;;
-;;; This program is free software; you can redistribute it and/or modify
+;;; This file is part of Skribilo.
+;;;
+;;; Skribilo is free software: you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2 of the License, or
+;;; the Free Software Foundation, either version 3 of the License, or
 ;;; (at your option) any later version.
 ;;;
-;;; This program is distributed in the hope that it will be useful,
+;;; Skribilo is distributed in the hope that it will be useful,
 ;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
 ;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ;;; GNU General Public License for more details.
 ;;;
 ;;; You should have received a copy of the GNU General Public License
-;;; along with this program; if not, write to the Free Software
-;;; Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-;;; USA.
+;;; along with Skribilo.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (skribilo engine latex)
   :use-module (skribilo lib)
@@ -41,7 +42,7 @@
            LaTeX TeX !latex
            skribe-color->latex-rgb))
 
-(fluid-set! current-reader %skribilo-module-reader)
+(skribilo-module-syntax)
 
 
 
@@ -355,6 +356,7 @@
 	 :delegate (find-engine 'base)
 	 :filter (make-string-replace latex-encoding)
 	 :custom '((documentclass "\\documentclass{article}")
+                   (encoding "UTF-8")
                    (class-has-chapters? #f)
 		   (usepackage "\\usepackage{epsfig}\n")
 		   (predocument "\\newdimen\\oldframetabcolsep\n\\newdimen\\oldcolortabcolsep\n\\newdimen\\oldpretabcolsep\n")
@@ -516,6 +518,16 @@
 		 (if dc
 		     (begin (display dc) (newline))
 		     (display "\\documentclass{article}\n")))
+
+              (cond-expand
+               (guile-2
+                (let ((encoding (engine-custom e 'encoding)))
+                  (set-port-encoding! (current-output-port) encoding)
+                  (set-port-conversion-strategy! (current-output-port) 'error)
+                  (if (string-ci=? encoding "UTF-8") ; FIXME: other encodings?
+                      (display "\\usepackage[utf8]{inputenc}\n"))))
+               (else #t))
+
 	      (if (latex-color? e)
 		  (display (engine-custom e 'color-usepackage)))
 	      (if (engine-custom e 'hyperref)
@@ -1745,8 +1757,3 @@
 ;*    Restore the base engine                                          */
 ;*---------------------------------------------------------------------*/
 (default-engine-set! (find-engine 'base))
-
-
-;;; Local Variables:
-;;; coding: latin-1
-;;; End:
