@@ -1,23 +1,24 @@
 ;;; eval.scm  --  Skribilo evaluator.
+;;; -*- coding: iso-8859-1 -*-
 ;;;
+;;; Copyright 2005, 2006, 2009, 2012  Ludovic Courts  <ludo@gnu.org>
 ;;; Copyright 2003, 2004  Erick Gallesio - I3S-CNRS/ESSI <eg@essi.fr>
-;;; Copyright 2005, 2006, 2007  Ludovic Courts  <ludovic.courtes@laas.fr>
 ;;;
 ;;;
-;;; This program is free software; you can redistribute it and/or modify
+;;; This file is part of Skribilo.
+;;;
+;;; Skribilo is free software: you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2 of the License, or
+;;; the Free Software Foundation, either version 3 of the License, or
 ;;; (at your option) any later version.
 ;;;
-;;; This program is distributed in the hope that it will be useful,
+;;; Skribilo is distributed in the hope that it will be useful,
 ;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
 ;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ;;; GNU General Public License for more details.
 ;;;
 ;;; You should have received a copy of the GNU General Public License
-;;; along with this program; if not, write to the Free Software
-;;; Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-;;; USA.
+;;; along with Skribilo.  If not, see <http://www.gnu.org/licenses/>.
 
 
 (define-module (skribilo evaluator)
@@ -49,7 +50,7 @@
 	     (srfi srfi-39))
 
 
-(fluid-set! current-reader %skribilo-module-reader)
+(skribilo-module-syntax)
 
 
 ;;;
@@ -59,8 +60,11 @@
   ;; Evaluate EXPR in the current module.  EXPR is an arbitrary S-expression
   ;; that may contain calls to the markup functions defined in a markup
   ;; package such as `(skribilo package base)', e.g., `(bold "hello")'.
-  (let ((opts (debug-options)))
-    (dynamic-wind
+  (cond-expand
+   (guile-2 (eval expr module))
+   (else
+    (let ((opts (debug-options)))
+      (dynamic-wind
         (lambda ()
           ;; Force use of the debugging evaluator so that we can track source
           ;; location.
@@ -70,7 +74,7 @@
           (eval expr module))
         (lambda ()
           ;; Restore previous evaluator options.
-          (debug-options opts)))))
+          (debug-options opts)))))))
 
 
 ;;;
@@ -188,6 +192,7 @@
 	   ;; Load it
 	   (with-input-from-file filep
 	     (lambda ()
+               (set-correct-file-encoding!)
 	       (evaluate-document-from-port (current-input-port) ei
                                             :module module
                                             :reader reader)))
@@ -215,6 +220,7 @@
 
     (with-input-from-file full-path
       (lambda ()
+        (set-correct-file-encoding!)
         (save-module-excursion
           (lambda ()
             (set-current-module module)
