@@ -1,27 +1,27 @@
-;;; index.scm
+;;; index.scm -- Document indices.        -*- coding: iso-8859-1 -*-
 ;;;
-;;; Copyright 2005, 2006, 2008  Ludovic Courts <ludo@gnu.org>
+;;; Copyright 2005, 2006, 2008, 2009  Ludovic Courts <ludo@gnu.org>
 ;;; Copyright 2003, 2004  Manuel Serrano
 ;;;
 ;;;
-;;; This program is free software; you can redistribute it and/or modify
+;;; This file is part of Skribilo.
+;;;
+;;; Skribilo is free software: you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2 of the License, or
+;;; the Free Software Foundation, either version 3 of the License, or
 ;;; (at your option) any later version.
 ;;;
-;;; This program is distributed in the hope that it will be useful,
+;;; Skribilo is distributed in the hope that it will be useful,
 ;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
 ;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ;;; GNU General Public License for more details.
 ;;;
 ;;; You should have received a copy of the GNU General Public License
-;;; along with this program; if not, write to the Free Software
-;;; Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-;;; USA.
+;;; along with Skribilo.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (skribilo index)
-  :use-syntax (skribilo utils syntax)
-  :use-syntax (skribilo lib)
+  :use-module (skribilo utils syntax)
+  :use-module (skribilo lib)
 
   :use-module (skribilo ast)
   :autoload   (srfi srfi-34)          (raise)
@@ -39,7 +39,7 @@
            default-index resolve-the-index))
 
 
-(fluid-set! current-reader %skribilo-module-reader)
+(skribilo-module-syntax)
 
 ;;; Author:  Manuel Serrano
 ;;; Commentary:
