@@ -1,28 +1,29 @@
 ;;; base.scm -- The base markup package of Skribe/Skribilo.
+;;; -*- coding: iso-8859-1 -*-
 ;;;
-;;; Copyright 2005, 2006, 2007, 2008  Ludovic Courts  <ludo@gnu.org>
+;;; Copyright 2005, 2006, 2007, 2008, 2009  Ludovic Courts  <ludo@gnu.org>
 ;;; Copyright 2003, 2004  Manuel Serrano
 ;;;
 ;;;
-;;; This program is free software; you can redistribute it and/or modify
+;;; This file is part of Skribilo.
+;;;
+;;; Skribilo is free software: you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2 of the License, or
+;;; the Free Software Foundation, either version 3 of the License, or
 ;;; (at your option) any later version.
 ;;;
-;;; This program is distributed in the hope that it will be useful,
+;;; Skribilo is distributed in the hope that it will be useful,
 ;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
 ;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ;;; GNU General Public License for more details.
 ;;;
 ;;; You should have received a copy of the GNU General Public License
-;;; along with this program; if not, write to the Free Software
-;;; Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-;;; USA.
+;;; along with Skribilo.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (skribilo package base)
-  :use-syntax (skribilo lib)
-  :use-syntax (skribilo utils syntax)
-  :use-syntax (ice-9 optargs)
+  :use-module (skribilo lib)
+  :use-module (skribilo utils syntax)
+  :use-module (ice-9 optargs)
 
   :use-module (skribilo ast)
   :use-module (skribilo resolve)
@@ -42,7 +43,7 @@
 
   :replace (symbol))
 
-(fluid-set! current-reader %skribilo-module-reader)
+(skribilo-module-syntax)
 
 ;;; Author: Manuel Serrano
 ;;; Commentary:
@@ -133,6 +134,31 @@
 		     ,@(the-options opts :ident :class)))
 	  (body #f))))
 
+;*---------------------------------------------------------------------*/
+;*    handle ...                                                       */
+;*---------------------------------------------------------------------*/
+(define-markup (handle :rest opts
+		       :key (ident #f) (class "handle") value section)
+   (let ((body (the-body opts)))
+      (cond
+	 (section
+	  (error 'handle "Illegal handle `section' option" section)
+	  (new unresolved
+             (loc  &invocation-location)
+	     (proc (lambda (n e env)
+		      (let ((s (resolve-ident section 'section n env)))
+			 (new handle
+                            (loc   &invocation-location)
+			    (ast s)))))))
+	 ((and (pair? body)
+	       (null? (cdr body))
+	       (markup? (car body)))
+	  (new handle
+             (loc &invocation-location)
+	     (ast (car body))))
+	 (else
+	  (skribe-error 'handle "Illegal handle" opts)))))
+
 ;*---------------------------------------------------------------------*/
 ;*    toc ...                                                          */
 ;*---------------------------------------------------------------------*/
@@ -200,7 +226,8 @@
 			opts
 			:key
 			(ident #f) (class "chapter")
-			title (html-title #f) (file #f) (toc #t) (number #t))
+			title (html-title #f) (info-node #f)
+                        (file #f) (toc #t) (number #t))
    (new container
       (markup 'chapter)
       (ident (or ident (symbol->string (gensym "chapter"))))
@@ -227,7 +254,7 @@
 			opts
 			:key
 			(ident #f) (class "section")
-			title (file #f) (toc #t) (number #t))
+			title info-node (file #f) (toc #t) (number #t))
    (new container
       (markup 'section)
       (ident (or ident (symbol->string (gensym "section"))))
@@ -255,7 +282,7 @@
 			   opts
 			   :key
 			   (ident #f) (class "subsection")
-			   title (file #f) (toc #t) (number #t))
+			   title info-node (file #f) (toc #t) (number #t))
    (new container
       (markup 'subsection)
       (ident (or ident (symbol->string (gensym "subsection"))))
@@ -280,7 +307,7 @@
 			      opts
 			      :key
 			      (ident #f) (class "subsubsection")
-			      title (file #f) (toc #f) (number #t))
+			      title info-node (file #f) (toc #f) (number #t))
    (new container
       (markup 'subsubsection)
       (ident (or ident (symbol->string (gensym "subsubsection"))))
@@ -961,31 +988,6 @@
 (define-processor-markup html-processor)
 (define-processor-markup tex-processor)
 
-;*---------------------------------------------------------------------*/
-;*    handle ...                                                       */
-;*---------------------------------------------------------------------*/
-(define-markup (handle :rest opts
-		       :key (ident #f) (class "handle") value section)
-   (let ((body (the-body opts)))
-      (cond
-	 (section
-	  (error 'handle "Illegal handle `section' option" section)
-	  (new unresolved
-             (loc  &invocation-location)
-	     (proc (lambda (n e env)
-		      (let ((s (resolve-ident section 'section n env)))
-			 (new handle
-                            (loc   &invocation-location)
-			    (ast s)))))))
-	 ((and (pair? body)
-	       (null? (cdr body))
-	       (markup? (car body)))
-	  (new handle
-             (loc &invocation-location)
-	     (ast (car body))))
-	 (else
-	  (skribe-error 'handle "Illegal handle" opts)))))
-
 ;*---------------------------------------------------------------------*/
 ;*    mailto ...                                                       */
 ;*    -------------------------------------------------------------    */
