@@ -1,22 +1,22 @@
 ;;; lout.scm  --  Lout implementation of the `eq' package.
 ;;;
-;;; Copyright 2005, 2006, 2007, 2008  Ludovic Courts <ludo@gnu.org>
+;;; Copyright 2005, 2006, 2007, 2008, 2010  Ludovic Courts <ludo@gnu.org>
 ;;;
 ;;;
-;;; This program is free software; you can redistribute it and/or modify
+;;; This file is part of Skribilo.
+;;;
+;;; Skribilo is free software: you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2 of the License, or
+;;; the Free Software Foundation, either version 3 of the License, or
 ;;; (at your option) any later version.
 ;;;
-;;; This program is distributed in the hope that it will be useful,
+;;; Skribilo is distributed in the hope that it will be useful,
 ;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
 ;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ;;; GNU General Public License for more details.
 ;;;
 ;;; You should have received a copy of the GNU General Public License
-;;; along with this program; if not, write to the Free Software
-;;; Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-;;; USA.
+;;; along with Skribilo.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (skribilo package eq lout)
   :use-module (skribilo package eq)
@@ -28,7 +28,7 @@
   :use-module (skribilo utils syntax)
   :use-module (srfi srfi-1))
 
-(fluid-set! current-reader %skribilo-module-reader)
+(skribilo-module-syntax)
 
 
 
@@ -59,9 +59,11 @@
 (markup-writer 'eq (find-engine 'lout)
    :options '(:inline? :align-with :div-style :mul-style :number)
    :before (lambda (node engine)
-             (let* ((parent (ast-parent node))
-                    (displayed? (is-markup? parent 'eq-display))
-                    (number (equation-number-string node)))
+             (let ((displayed? (case (markup-option node :inline?)
+                                 ((auto) (is-markup? (ast-parent node)
+                                                     'eq-display))
+                                 (else   (not (markup-option node :inline?)))))
+                   (number     (equation-number-string node)))
                ;; Note: The `@BypassNumber' option appeared in Lout 3.36.
                (if (and displayed? (not (*embedded-renderer*)))
                    (display (if (string? number)
