@@ -1,23 +1,24 @@
 ;;; source.scm	-- Highlighting source files.
+;;; -*- coding: iso-8859-1 -*-
 ;;;
-;;; Copyright 2005, 2008  Ludovic Courts <ludo@gnu.org>
+;;; Copyright 2005, 2008, 2009, 2010  Ludovic Courts <ludo@gnu.org>
 ;;; Copyright 2003, 2004  Erick Gallesio - I3S-CNRS/ESSI <eg@essi.fr>
 ;;;
 ;;;
-;;; This program is free software; you can redistribute it and/or modify
+;;; This file is part of Skribilo.
+;;;
+;;; Skribilo is free software: you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2 of the License, or
+;;; the Free Software Foundation, either version 3 of the License, or
 ;;; (at your option) any later version.
 ;;;
-;;; This program is distributed in the hope that it will be useful,
+;;; Skribilo is distributed in the hope that it will be useful,
 ;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
 ;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ;;; GNU General Public License for more details.
 ;;;
 ;;; You should have received a copy of the GNU General Public License
-;;; along with this program; if not, write to the Free Software
-;;; Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-;;; USA.
+;;; along with Skribilo.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (skribilo source)
   :export (<language> language? language-extractor language-fontifier
@@ -42,7 +43,7 @@
   :use-module (ice-9 rdelim))
 
 
-(fluid-set! current-reader %skribilo-module-reader)
+(skribilo-module-syntax)
 
 
 ;;;
@@ -109,6 +110,7 @@
 					      (path (*source-path*)))))
 	(with-input-from-file p
 	  (lambda ()
+            (set-correct-file-encoding!)
 	    (if (> (*verbose*) 0)
 		(format (current-error-port) "  [source file: ~S]\n" p))
 	    (let ((startl (if (string? start) (string-length start) -1))
@@ -193,6 +195,7 @@
 
 	 (else
 	  (let ((ip (open-input-file p)))
+             (set-correct-file-encoding! ip)
 	     (if (> (*verbose*) 0)
 		 (format (current-error-port) "  [source file: ~S]\n" p))
 	     (if (not (input-port? ip))
