@@ -1,12 +1,12 @@
 ;;; sui.scm -- Skribe URL Indices
 ;;;
-;;; Copyright 2005, 2006, 2007, 2008  Ludovic Courts <ludo@gnu.org>
+;;; Copyright 2005, 2006, 2007, 2008, 2009, 2012  Ludovic Courts <ludo@gnu.org>
 ;;; Copyright 2003, 2004  Manuel Serrano
 ;;;
 ;;;
 ;;; This program is free software; you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2 of the License, or
+;;; the Free Software Foundation; either version 3 of the License, or
 ;;; (at your option) any later version.
 ;;;
 ;;; This program is distributed in the hope that it will be useful,
@@ -26,7 +26,6 @@
   :autoload   (skribilo reader)     (make-reader)
   :autoload   (skribilo engine)     (find-engine)
   :autoload   (skribilo evaluator)  (evaluate-document)
-  :autoload   (skribilo engine html)(html-file)
   :use-module (skribilo condition)
   :use-module (skribilo utils strings)
   :use-module (skribilo utils syntax)
@@ -41,7 +40,7 @@
            sui-find-ref sui-search-ref sui-filter
            document-sui sui-referenced-file sui-marks sui-blocks))
 
-(fluid-set! current-reader %skribilo-module-reader)
+(skribilo-module-syntax)
 
 
 ;;; Author: Manuel Serrano, Ludovic Courts
@@ -294,7 +293,13 @@
 ;*    sui-referenced-file ...                                          */
 ;*---------------------------------------------------------------------*/
 (define (sui-referenced-file n e)
-   (let ((file (html-file n e)))
+
+   ;; Hack to avoid a compile-time dependency on the HTML engine, which would
+   ;; create a dependency loop:
+   ;; (package base) -> (sui) -> (engine html) -> (package base).
+
+   (let* ((html-file (@ (skribilo engine html) html-file))
+          (file      (html-file n e)))
       (if (member (file-suffix file) '("skb" "sui" "skr" "html"))
 	  (string-append (strip-ref-base (file-prefix file)) ".html")
 	  file)))
