@@ -1,23 +1,24 @@
 ;;; writer.scm  --  Markup writers.
+;;; -*- coding: iso-8859-1 -*-
 ;;;
-;;; Copyright 2005, 2006, 2008  Ludovic Courts <ludo@gnu.org>
+;;; Copyright 2005, 2006, 2008, 2009, 2012  Ludovic Courts <ludo@gnu.org>
 ;;; Copyright 2003, 2004  Erick Gallesio - I3S-CNRS/ESSI <eg@essi.fr>
 ;;;
 ;;;
-;;; This program is free software; you can redistribute it and/or modify
+;;; This file is part of Skribilo.
+;;;
+;;; Skribilo is free software: you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2 of the License, or
+;;; the Free Software Foundation, either version 3 of the License, or
 ;;; (at your option) any later version.
 ;;;
-;;; This program is distributed in the hope that it will be useful,
+;;; Skribilo is distributed in the hope that it will be useful,
 ;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
 ;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ;;; GNU General Public License for more details.
 ;;;
 ;;; You should have received a copy of the GNU General Public License
-;;; along with this program; if not, write to the Free Software
-;;; Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-;;; USA.
+;;; along with Skribilo.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (skribilo writer)
   :export (<writer> writer? writer-options writer-ident
@@ -34,15 +35,13 @@
   :use-module (srfi srfi-35)
   :use-module (skribilo condition)
   :use-module (skribilo debug)
-  :use-module (skribilo output)
   :use-module (skribilo ast)
-  :use-module ((skribilo lib) :select (%procedure-arity))
 
   :use-module (oop goops)
   :use-module (ice-9 optargs))
 
 
-(fluid-set! current-reader %skribilo-module-reader)
+(skribilo-module-syntax)
 
 
 
@@ -89,6 +88,12 @@
 	     (proc node e)))))
 
 
+(define (%procedure-arity proc)
+  ;; Return the minimum number of required arguments for PROC.
+  (cond-expand (guile-2
+                (car (procedure-minimum-arity proc)))
+               (else
+                (car (procedure-property proc 'arity)))))
 
 (define (make-writer-predicate markup predicate class)
   (let* ((t2 (if class
@@ -100,7 +105,7 @@
 	  ((or (not (procedure? predicate))
                (not (eq? (%procedure-arity predicate) 2)))
            (raise (condition (&invalid-argument-error
-                              (proc-name make-writer-predicate)
+                              (proc-name 'make-writer-predicate)
                               (argument  predicate)))))
 	  (else
 	   (if (procedure? t2)
@@ -154,11 +159,71 @@
       (else
        (let ((m  (make-writer-predicate markup predicate class))
 	     (ac (if (eq? action 'unspecified)
-		     (lambda (n e) (output (markup-body n) e))
+		     (lambda (n e)
+                       ((@ (skribilo output) output)
+                        (markup-body n) e))
 		     action)))
 	 (engine-add-writer! e markup m predicate
 			     options before ac after class validate))))))
 
+(define (engine-add-writer! e ident pred upred opt before action
+			    after class valid)
+  ;; Add a writer to engine E.  If IDENT is a symbol, then it should denote
+  ;; a markup name and the writer being added is specific to that markup.  If
+  ;; IDENT is `#t' (for instance), then it is assumed to be a ``free writer''
+  ;; that may apply to any kind of markup for which PRED returns true.
+
+  (define (check-procedure name proc arity)
+    (if (or (not (procedure? proc))
+            (not (equal? (%procedure-arity proc) arity)))
+        (raise (condition (&invalid-argument-error
+                           (proc-name 'engine-add-writer!)
+                           (argument  proc))))
+        #t))
+
+  (define (check-output name proc)
+    (and proc (or (string? proc) (check-procedure name proc 2))))
+
+  ;;
+  ;; Engine-add-writer! starts here
+  ;;
+  (or (engine? e)
+      (raise (condition (&invalid-argument-error
+                         (proc-name 'engine-add-writer!)
+                         (argument  e)))))
+
+  ;; check the options
+  (or (eq? opt 'all) (list? opt)
+      (raise (condition (&invalid-argument-error
+                         (proc-name 'engine-add-writer!)
+                         (argument  opt)))))
+
+  ;; check the correctness of the predicate
+  (if pred
+      (check-procedure "predicate" pred 2))
+
+  ;; check the correctness of the validation proc
+  (if valid
+      (check-procedure "validate" valid 2))
+
+  ;; check the correctness of the three actions
+  (check-output "before" before)
+  (check-output "action" action)
+  (check-output "after" after)
+
+  ;; create a new writer and bind it
+  (let ((n (make <writer>
+	     :ident (if (symbol? ident) ident 'all)
+	     :class class :pred pred :upred upred :options opt
+	     :before before :action action :after after
+	     :validate valid)))
+    (if (symbol? ident)
+	(let ((writers (slot-ref e 'writers)))
+	  (hashq-set! writers ident
+		      (cons n (hashq-ref writers ident '()))))
+	(slot-set! e 'free-writers
+		   (cons n (slot-ref e 'free-writers))))
+    n))
 
 
 ;;;
@@ -195,7 +260,7 @@
   (define (matching-writer writers)
     (find (lambda (w)
 	    (and (if class (equal? (writer-class w) class) #t)
-		 (or (unspecified? pred)
+		 (or (eq? pred 'unspecified)
 		     (eq? (slot-ref w 'upred) pred))))
 	  writers))
 
@@ -251,13 +316,13 @@
 
 
 (define* (copy-markup-writer markup old-engine ;; #:optional new-engine
-			      :key (predicate 'unspecified)
-				   (class 'unspecified)
-				   (options 'unspecified)
-				   (validate 'unspecified)
-				   (before 'unspecified)
-				   (action 'unspecified)
-				   (after 'unspecified)
+			      :key (predicate *unspecified*)
+				   (class     *unspecified*)
+				   (options   *unspecified*)
+				   (validate  *unspecified*)
+				   (before    *unspecified*)
+				   (action    *unspecified*)
+				   (after     *unspecified*)
                               :rest args)
     (define new-engine
       ;; XXX: Work around `lambda*' suckingness (see `markup-writer').
